@@ -3,7 +3,7 @@
  *		  When the mpars structure is changed,
  *		  change these define's too.
  *
- *		$Id: configsym.h,v 1.1.1.1 2003/03/30 18:55:48 al-guest Exp $
+ *		$Id: configsym.h,v 1.5 2006/04/02 09:52:30 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -38,7 +38,7 @@ struct pars {
   /* Try doing this in PASCAL !! :-) */
   char value[PARS_VAL_LEN];
   int flags;
-  char *desc;
+  const char *desc;
 };
 extern struct pars mpars[];
 
@@ -51,14 +51,18 @@ extern struct pars mpars[];
 struct macs {
   char value[MAC_LEN];
   int flags;
-  char *desc;
+  const char *desc;
 };
 extern struct macs mmacs[];
 
+enum config_type {
+  CONFIG_GLOBAL,
+  CONFIG_PERSONAL,
+};
 
-#define CHANGED	3
-#define PRIVATE	4
-#define PUBLIC	8
+#define ADM_CHANGE	1
+#define USR_CHANGE	2
+#define CHANGED		(ADM_CHANGE | USR_CHANGE)
 
 #define PROTO_BASE	0
 #define MAXPROTO	12
@@ -149,7 +153,13 @@ extern struct macs mmacs[];
 #define P_LOGCONN	mpars[84].value  /* Log connects and hangups */
 #define P_LOGXFER	mpars[85].value  /* Log file transfers */
 
-#define P_MULTILINE 	mpars[86].value  /* Multi-node untag  er 18-Apr-99 */
+#define P_MULTILINE	mpars[86].value  /* Multi-node untag  er 18-Apr-99 */
+
+/* Terminal behaviour */
+#define P_LOCALECHO	mpars[87].value
+#define P_ADDLINEFEED	mpars[88].value
+
+#define P_ANSWERBACK    mpars[89].value  /* User defined answerback string */
 
 /* fmg - macros struct */
 
