@@ -19,7 +19,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: functions.c,v 1.1.1.1 2003/03/30 18:55:49 al-guest Exp $")
+RCSID("$Id: functions.c,v 1.2 2003/07/20 18:55:40 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
@@ -27,41 +27,40 @@ RCSID("$Id: functions.c,v 1.1.1.1 2003/03/30 18:55:49 al-guest Exp $")
 /*
  * Send a string to the modem.
  */
-void m_puts(s)
-char *s;
+void m_puts(char *s)
 {
   char c;
 
-  while(*s) {
-  	if (*s == '^' && (*(s + 1))) {
-  		s++;
-  		if (*s == '^')
-  			c = *s;
-  		else
-  			c = (*s) & 31;
-  	} else
-  		c = *s;
-  	if (c == '~')
-  		sleep(1);
-  	else	
-  		write(portfd, &c, 1);
-  	s++;
+  while (*s) {
+    if (*s == '^' && *(s + 1)) {
+      s++;
+      if (*s == '^')
+	c = *s;
+      else
+	c = *s & 31;
+    } else
+      c = *s;
+    if (c == '~')
+      sleep(1);
+    else	
+      write(portfd, &c, 1);
+    s++;
   }
 }
 
 /* Hangup. */
-void m_hangup()
+void m_hangup(void)
 {
-  int sec=1;
+  int sec = 1;
 
   if (isdigit(P_MDROPDTR[0]))
-    sscanf(P_MDROPDTR,"%2d",&sec);
+    sscanf(P_MDROPDTR, "%2d", &sec);
 
   if (P_MDROPDTR[0] == 'Y' || (isdigit(P_MDROPDTR[0]) && sec > 0)) {
-  	m_dtrtoggle(portfd, sec);  /* jl 22.06.97 */
+    m_dtrtoggle(portfd, sec);  /* jl 22.06.97 */
   } else {
-  	m_puts(P_MHANGUP);
-  	sleep(1);
+    m_puts(P_MHANGUP);
+    sleep(1);
   }
   /* If we don't have DCD support fake DCD dropped */
   bogus_dcd = 0;
