@@ -16,29 +16,24 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: help.c,v 1.1.1.1 2003/03/30 18:55:51 al-guest Exp $")
+RCSID("$Id: help.c,v 1.6 2005/10/31 10:31:38 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
 
 /* Draw a help screen and return the keypress code. */
-int help()
+int help(void)
 {
   WIN *w;
   int c;
-  int i;
+  int i = 1;
   int x1, x2;
 
-#if HISTORY
-  i = 1;
-#else
-  i = 0;
-#endif
   x1 = (COLS / 2) - 34;
   x2 = (COLS / 2) + 32;
   w = wopen(x1, 2, x2, 20 + i, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-  
+
   wlocate(w, 21, 0);
   wputs(w, _("Minicom Command Summary"));
   wlocate(w, 10, 2);
@@ -62,15 +57,10 @@ int help()
   wputs(w, _(" send break.........F  initialize Modem...M | Quit with no reset.Q\n"));
   wputs(w, _(" Terminal settings..T  run Kermit.........K | Cursor key mode....I\n"));
   wputs(w, _(" lineWrap on/off....W"));
-#ifdef HAVE_SELECT
-  wputs(w, _("  local Echo on/off..E | Help screen........Z"));
-#else
-  wputs(w, _("                       | Help screen........Z"));
-#endif
-#if HISTORY
+  wputs(w, _("  local Echo on/off..E | Help screen........Z\n"));
+  wputs(w, _(" Paste file.........Y"));
   wlocate(w, 44, 13);
   wputs(w, _("| scroll Back........B"));
-#endif
 
   wlocate(w, 13, 16 + i);
   wputs(w, _("Written by Miquel van Smoorenburg 1991-1995"));
