@@ -1,7 +1,7 @@
 /*
  * Keyserv.c	A process that translates keypresses to
  *		ANSI or VT102 escape sequences.
- * 		Communications with this process from minicom
+ *		Communications with this process from minicom
  *		goes through pipes, file descriptors 3 & 4.
  *
  *		This file is part of the minicom communications package,
@@ -17,7 +17,10 @@
 #endif
 
 #include "rcsid.h"
-RCSID(PKG_VER "$Id: keyserv.c,v 1.1.1.1 2003/03/30 18:55:51 al-guest Exp $")
+RCSID("$Id: keyserv.c,v 1.3 2005/08/04 20:33:33 al-guest Exp $")
+
+#include <unistd.h>
+#include <stdlib.h>
 
 #include "port.h"
 #include "minicom.h"
@@ -34,7 +37,6 @@ RCSID(PKG_VER "$Id: keyserv.c,v 1.1.1.1 2003/03/30 18:55:51 al-guest Exp $")
 int keypadmode = NORMAL;
 int cursormode = NORMAL;
 
-char *_tptr = (char *)NULL;	/* Pointer to termcap information */
 int mode = EVT100;		/* Emulation mode selector */
 int parent;			/* Process ID of minicom */
 jmp_buf mainloop;		/* To jump to after a 'HELLO' signal */
@@ -42,7 +44,6 @@ char **escseq;			/* Translation table to use */
 static int argument;		/* Argument to 'HELLO' command */
 static int esc_char = 1;	/* Escape character (initially ^A) */
 static int bs_code = 8;		/* Code that backspace key sends */
-extern int pendingkeys;		/* From wkeys.c */
 
 char *st_vtesc[] = {
   "", "\033OP", "\033OQ", "\033OR", "\033OS", "", "", "", "", "", "",
@@ -63,22 +64,21 @@ char *ansiesc[] = {
  * We got a signal. This means that there is some information for us.
  * Read it, and jump to the main loop.
  */
-/*ARGSUSED*/
-void handler(dummy)
-int dummy;
+void handler(int dummy)
 {
   unsigned char buf[8];
   int n;
 
+  (void)dummy;
   signal(HELLO, handler);
   n = read(from_minicom, buf, 8);
   if (n <= 0) {
-  	n = 2;
-  	buf[0] = 0;
+    n = 2;
+    buf[0] = 0;
   }
   if (n % 2 == 1) {
-	n++;
-	read(from_minicom, buf + n, 1);
+    n++;
+    read(from_minicom, buf + n, 1);
   }
   argument = buf[n-1];
   longjmp(mainloop, (int)buf[n - 2]);
@@ -87,8 +87,7 @@ int dummy;
 /*
  * Send a string to the modem
  */
-void sendstr(s)
-char *s;
+void sendstr(char *s)
 {
   write(1, s, strlen(s));
 }
@@ -96,16 +95,17 @@ char *s;
 /*
  * Main program of keyserv.
  */
-int main(argc, argv)
-int argc;
-char **argv;
+int main(int argc, char **argv)
 {
   int c;
   char ch;
   int f, fun;
   int stopped = 0;
 
-  parent = atoi(argv[1]);
+  if (argc < 2 || (parent = atoi(argv[1])) == 0) {
+    printf("Usage: %s <parent>\n", *argv);
+    exit(1);
+  }
   
   /* Initialize signal handlers */
   /* signal(SIGHUP, SIG_IGN); */
@@ -122,93 +122,93 @@ char **argv;
   escseq = st_vtesc;
 
   /* Cbreak, no echo (minicom itself sets to raw if needed) */
-  (void) setcbreak(1);
+  setcbreak(1);
 
   if ((fun = setjmp(mainloop)) != 0) {
+    switch (fun) {
 
-  	switch(fun) {
+      /* We come here after minicom has told us something */
 
-  	/* We come here after minicom has told us something */
-
-  	case KVT100: /* VT100 keyboard */
-		mode = EVT100;
-		escseq = st_vtesc;
-		break;
-	case KANSI:  /* ANSI keyboard */
-		mode = EANSI;
-		escseq = ansiesc;
-		break;
-	case KKPST: /* Keypad in standard mode, not used */
-		keypadmode = NORMAL; 
-		break;
-	case KKPAPP: /* Keypad in applications mode, not used */
-		keypadmode = APPL;
-		break;
-	case KCURST: /* Standard cursor keys */
-		cursormode = NORMAL;
-		if (mode == EVT100)
-			escseq = st_vtesc;
-		break;
-	case KCURAPP: /* cursor keys in applications mode */
-		cursormode = APPL;
-		if (mode == EVT100)
-			escseq = app_vtesc;
-		break;
-	case KSTOP:  /* Sleep until further notice */
-		stopped = 1;
-		break;
-	case KSIGIO: /* Wait for keypress and tell parent */
-		kill(parent, ACK);
-		f = read(0, &ch, 1);
-		if (f == 1) {
-			write(to_minicom, &ch, 1);
-			(void) kill(parent, HELLO);
-		}
-		break;
-	case KSTART: /* Restart when stopped */
-		stopped  = 0;
-		break;
-	case KSETBS: /* Set code that BS key sends */
-		bs_code = argument;
-		break;
-	case KSETESC: /* Set escape character */
-		esc_char = argument;
-		break;
-	default:
-		break;
-    }
-    if (fun != KSIGIO) {
-	kill(parent, ACK);
+      case KVT100: /* VT100 keyboard */
+        mode = EVT100;
+        escseq = st_vtesc;
+        break;
+      case KANSI:  /* ANSI keyboard */
+        mode = EANSI;
+        escseq = ansiesc;
+        break;
+      case KKPST: /* Keypad in standard mode, not used */
+        keypadmode = NORMAL; 
+        break;
+      case KKPAPP: /* Keypad in applications mode, not used */
+        keypadmode = APPL;
+        break;
+      case KCURST: /* Standard cursor keys */
+        cursormode = NORMAL;
+        if (mode == EVT100)
+          escseq = st_vtesc;
+        break;
+      case KCURAPP: /* cursor keys in applications mode */
+        cursormode = APPL;
+        if (mode == EVT100)
+          escseq = app_vtesc;
+        break;
+      case KSTOP:  /* Sleep until further notice */
+        stopped = 1;
+        break;
+      case KSIGIO: /* Wait for keypress and tell parent */
+        kill(parent, ACK);
+        f = read(0, &ch, 1);
+        if (f == 1) {
+          write(to_minicom, &ch, 1);
+          kill(parent, HELLO);
+        }
+        break;
+      case KSTART: /* Restart when stopped */
+        stopped  = 0;
+        break;
+      case KSETBS: /* Set code that BS key sends */
+        bs_code = argument;
+        break;
+      case KSETESC: /* Set escape character */
+        esc_char = argument;
+        break;
+      default:
+        break;
     }
+    if (fun != KSIGIO)
+      kill(parent, ACK);
   }
   /* Wait if stopped */
-  if (stopped) pause();
+  if (stopped)
+    pause();
 
   /* Main loop: read keyboard, send to modem */
-  while(1) {
-  	c = wxgetch();
-  	if (c > 256 && c < 256 + NUM_KEYS) {
-  		sendstr(escseq[c - 256]);
-  	}
-  	if (c < 256) {
-  		if (c == K_ERA) c = bs_code;
-  		ch = c;
-  		/* Test for escape characters */
-  		if (c == esc_char || (esc_char == 128 && c > 128)) { 
-			/* If we typed too fast, and the escape sequence
-			 * was not that of a function key, the next key
-			 * is already in the buffer.
-			 */
-			if (c == esc_char && pendingkeys > 0) {
-				ch = wxgetch();
-			}
-  			write(to_minicom, &ch, 1);
-  			(void) kill(parent, HELLO);
-  		} else {
-  			write(1, &ch, 1);
-  		}
-  	}
+  while (1) {
+    c = wxgetch();
+    if (c > 256 && c < 256 + NUM_KEYS) {
+      sendstr(escseq[c - 256]);
+    }
+    if (c < 256) {
+      if (c == K_ERA)
+        c = bs_code;
+      ch = c;
+      /* Test for escape characters */
+      if (c == esc_char || (esc_char == 128 && c > 128)) { 
+        /* If we typed too fast, and the escape sequence
+         * was not that of a function key, the next key
+         * is already in the buffer.
+         */
+        if (c == esc_char && pendingkeys > 0) {
+          ch = wxgetch();
+        }
+        write(to_minicom, &ch, 1);
+        kill(parent, HELLO);
+      } else {
+        write(1, &ch, 1);
+      }
+    }
   }
-  /*NOTREACHED*/
-  return(0);
+
+  return 0;
 }
