@@ -4,7 +4,7 @@
  *		not application dependant. It maybe a bit of overhead
  *		but simplifies porting greatly.
  *
- *		$Id: port.h,v 1.2 2003/03/30 19:33:25 godisch Exp $
+ *		$Id: port.h,v 1.5 2005/10/31 10:31:38 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -21,17 +21,17 @@
 #  include <sys/param.h>
 #endif
 #include <sys/types.h>
-#ifdef HAVE_UNISTD_H 
+#ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #  include <stdlib.h>
 #else
-   char *getenv();
+   char *getenv(void);
 #endif
 #ifdef HAVE_TERMCAP_H
 #  include <termcap.h>
 #else
-  char *tgetstr(), *tgoto();
-  int tgetent(), tputs(), tgetnum(), tgetflag();
+  char *tgetstr(void), *tgoto(void);
+  int tgetent(void), tputs(void), tgetnum(void), tgetflag(void);
 #endif
 #ifdef _UWIN2P0
 # include <time.h>
@@ -84,24 +84,13 @@
 #  endif
 #endif
 
-/* A general macro for prototyping. */
-#ifndef _PROTO
-#  if __STDC__
-#    define _PROTO(fun, args) fun args
-#  else
-#  define _PROTO(fun, args) fun()
-#  endif
-#endif
-
 #ifdef _COH42
 #  define time_t long
 #endif
 
 /* Enable music routines. Could we use defined(i386) here? */
 #if defined(__linux__) || defined(_COH42) || defined(_SCO)
-#  ifdef HAVE_SELECT
-#    define VC_MUSIC 1
-#  endif
+# define VC_MUSIC 1
 #endif
 
 /* Availability of setreuid(uid_t, uid_t) */
@@ -115,3 +104,5 @@
 #    define HAS_FCHOWN
 #  endif
 #endif
+
+extern char **environ;
