@@ -5,6 +5,8 @@
  *		included. This file is only included from sysdep[12].c
  *		anyway!
  *
+ *		$Id: sysdep.h,v 1.3 2003/04/19 16:17:33 al-guest Exp $
+ *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -13,42 +15,41 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  */
+#ifdef HAVE_FEATURES_H
+#include <features.h>
+#endif
 #include <sys/types.h>
+
 /* Include standard Posix header files. */
-#if defined (_POSIX) || defined(_BSD43)
+#ifdef HAVE_UNISTD_H
 #  include <stdlib.h>
 #  include <unistd.h>
 #endif
-#ifndef _COH3
+#ifdef HAVE_SYS_WAIT_H /* coherent 3 doesn't have it ? */
 #  include <sys/wait.h>
 #endif
 /* Now see if we need to use sgtty, termio or termios. */
 #ifdef _SCO
 #  define _IBCS2 /* So we get struct winsize :-) */
 #endif
-#if defined (_SYSV)
-#  if !defined(_POSIX) || defined(_NO_TERMIOS)
-#    include <sys/termio.h>
-#  else
-#    include <sys/termios.h>
-#  endif
+#ifdef POSIX_TERMIOS
+#  include <termios.h>
 #else
-#  if defined(_POSIX) && !defined(_NO_TERMIOS)
+#  ifdef HAVE_TERMIO_H
 #    include <termios.h>
 #  else
 #    define _V7
-#    include <sgtty.h>
+#    ifdef HAVE_SGTTY_H
+#      include <sgtty.h>
+#    endif
 #  endif
 #endif
 /* Some system-specific include files for modem control. */
 #ifdef _HPUX_SOURCE
 #  include <sys/modem.h>
 #endif
-#if defined(_BSD43) || defined (_SYSV)
-#    include <sys/ioctl.h>
-#endif
-#ifdef _COHERENT
-#  include <sgtty.h>
+#ifdef HAVE_SYS_IOCTL_H 
+#  include <sys/ioctl.h>
 #endif
 #ifdef _DGUX_SOURCE
 #  include <sys/termiox.h>
@@ -129,7 +130,7 @@
 
 /* If this is SysV without Posix, emulate Posix. */
 #if defined(_SYSV)
-#if !defined(_POSIX) || defined(_NO_TERMIOS)
+#if !defined(_POSIX) || !defined(HAVE_TERMIOS_H)
 #  define termios termio
 #  ifndef TCSANOW
 #    define TCSANOW 0
@@ -145,7 +146,7 @@
 #endif
 
 /* Redefine cfset{i,o}speed for Linux > 1.1.68 && libc < 4.5.21 */
-#if defined (__linux__) && defined(CBAUDEX)
+#if defined (__GLIBC__) && defined(CBAUDEX)
 #  undef cfsetispeed
 #  undef cfsetospeed
 #  define cfsetispeed(xtty, xspd) \
