@@ -30,14 +30,13 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: sysdep1.c,v 1.3 2003/04/01 23:59:51 al-guest Exp $")
+RCSID("$Id: sysdep1.c,v 1.5 2005/08/04 20:33:34 al-guest Exp $")
 
 #include "sysdep.h"
 #include "minicom.h"
 
 /* Set hardware flow control. */
-void m_sethwf(fd, on)
-int fd, on;
+void m_sethwf(int fd, int on)
 {
 #ifdef _DGUX_SOURCE
   struct termiox x;
@@ -48,35 +47,34 @@ int fd, on;
 
 #ifdef USE_SOCKET
   if (portfd_is_socket)
-  	return;
+	return;
 #endif
 
 #ifdef POSIX_TERMIOS
   tcgetattr(fd, &tty);
   if (on)
-	tty.c_cflag |= CRTSCTS;
+    tty.c_cflag |= CRTSCTS;
   else
-	tty.c_cflag &= ~CRTSCTS;
+    tty.c_cflag &= ~CRTSCTS;
   tcsetattr(fd, TCSANOW, &tty);
 #endif
 
 #ifdef _DGUX_SOURCE
   if (ioctl(fd, TCGETX, &x) < 0) {
-	fprintf(stderr, _("can't get termiox attr.\n"));
-	return;
+    fprintf(stderr, _("can't get termiox attr.\n"));
+    return;
   }
   x.x_hflag = on ? RTSXOFF|CTSXON : 0;
 
   if (ioctl(fd, TCSETX, &x) < 0) {
-	fprintf(stderr, _("can't set termiox attr.\n"));
-	return;
+    fprintf(stderr, _("can't set termiox attr.\n"));
+    return;
   }
 #endif
 }
 
 /* Set RTS line. Sometimes dropped. Linux specific? */
-void m_setrts(fd)
-int fd;
+void m_setrts(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -99,9 +97,7 @@ int fd;
 /*
  * Drop DTR line and raise it again.
  */
-void m_dtrtoggle(fd,sec) 
-int fd;
-int sec;
+void m_dtrtoggle(int fd, int sec)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -127,7 +123,7 @@ int sec;
     cfsetospeed(&tty, B0);
     cfsetispeed(&tty, B0);
     tcsetattr(fd, TCSANOW, &tty);
-    if (sec>0) {
+    if (sec > 0) {
       sleep(sec);
       tcsetattr(fd, TCSANOW, &old);
     }
@@ -137,13 +133,13 @@ int sec;
 
     /* Just drop speed to 0 and back to normal again */
     struct sgttyb sg, ng;
-    
+
     ioctl(fd, TIOCGETP, &sg);
     ioctl(fd, TIOCGETP, &ng);
-    
+
     ng.sg_ispeed = ng.sg_ospeed = 0;
     ioctl(fd, TIOCSETP, &ng);
-    if (sec>0) {
+    if (sec > 0) {
       sleep(sec);
       ioctl(fd, TIOCSETP, &sg);
     }
@@ -155,7 +151,7 @@ int sec;
     ioctl(fd, MCSETAF, &mflag);
     ioctl(fd, MCGETA, &mflag);
     mflag = MRTS | MDTR;
-    if (sec>0) {
+    if (sec > 0) {
       sleep(sec);
       ioctl(fd, MCSETAF, &mflag);
     }
@@ -168,9 +164,8 @@ int sec;
 /*
  * Send a break
  */
-void m_break(fd)
-int fd;
-{ 
+void m_break(int fd)
+{
 #ifdef USE_SOCKET
   if (portfd_is_socket)
     return;
@@ -203,8 +198,7 @@ int fd;
 /*
  * Get the dcd status
  */
-int m_getdcd(fd)
-int fd;
+int m_getdcd(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket) {
@@ -218,13 +212,13 @@ int fd;
 #ifdef TIOCMODG
   {
     int mcs=0;
-     
+
     ioctl(fd, TIOCMODG, &mcs);
-    return(mcs & TIOCM_CAR ? 1 : 0);
+    return mcs & TIOCM_CAR ? 1 : 0;
   }
 #else
   (void)fd;
-  return(0); /* Impossible!! (eg. Coherent) */
+  return 0; /* Impossible!! (eg. Coherent) */
 #endif
 }
 
@@ -244,8 +238,7 @@ static int m_word;
 /*
  * Save the state of a port
  */
-void m_savestate(fd)
-int fd;
+void m_savestate(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -270,8 +263,7 @@ int fd;
 /*
  * Restore the state of a port
  */
-void m_restorestate(fd)
-int fd;
+void m_restorestate(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -284,7 +276,7 @@ int fd;
   ioctl(fd, TIOCSETP, &sg);
   ioctl(fd, TIOCSETC, &tch);
 #  endif
-#  ifdef _BSD43  
+#  ifdef _BSD43
   ioctl(fd, TIOCLSET, &lsw);
 #  endif
 #endif
@@ -297,9 +289,8 @@ int fd;
  * Set the line status so that it will not kill our process
  * if the line hangs up.
  */
-/*ARGSUSED*/ 
-void m_nohang(fd)
-int fd;
+/*ARGSUSED*/
+void m_nohang(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -330,9 +321,7 @@ int fd;
 /*
  * Set hangup on close on/off.
  */
-void m_hupcl(fd, on)
-int fd;
-int on;
+void m_hupcl(int fd, int on)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -342,12 +331,12 @@ int on;
 #ifdef POSIX_TERMIOS
   {
     struct termios sgg;
-    
+
     tcgetattr(fd, &sgg);
     if (on)
-	  sgg.c_cflag |= HUPCL;
+      sgg.c_cflag |= HUPCL;
     else
-	  sgg.c_cflag &= ~HUPCL;
+      sgg.c_cflag &= ~HUPCL;
     tcsetattr(fd, TCSANOW, &sgg);
   }
 #endif
@@ -357,27 +346,26 @@ int on;
  * See if there is input waiting.
  * returns: 0=nothing, >0=something, -1=can't.
  */
-int m_readchk(fd)
-int fd;
+int m_readchk(int fd)
 {
 #ifdef FIONREAD
   long i = -1;
 
-  (void) ioctl(fd, FIONREAD, &i);
-  return((int)i);
+  ioctl(fd, FIONREAD, &i);
+  return (int)i;
 #else
 #  if defined(F_GETFL) && defined(O_NDELAY)
   int i, old;
   char c;
 
   old = fcntl(fd, F_GETFL, 0);
-  (void) fcntl(fd, F_SETFL, old | O_NDELAY);
+  fcntl(fd, F_SETFL, old | O_NDELAY);
   i = read(fd, &c, 1);
-  (void) fcntl(fd, F_SETFL, old);
+  fcntl(fd, F_SETFL, old);
 
-  return(i);
+  return i;
 #  else
-  return(-1);
+  return -1;
 #  endif
 #endif
 }
@@ -386,38 +374,32 @@ int fd;
  * Get maximum speed.
  * Returns maximum speed / 100. (192-1152)
  */
-int m_getmaxspd()
+int m_getmaxspd(void)
 {
 #ifdef B230400
-  return(2304);
+  return 2304;
 #elif defined(B115200)
-  return(1152);
+  return 1152;
 #elif defined(B57600)
-  return(576);
+  return 576;
 #elif defined(B38400)
-  return(384);
+  return 384;
 #elif defined(EXTB)
-  return(384);
+  return 384;
 #elif defined(B19200)
-  return(192);
+  return 192;
 #elif defined(EXTA)
-  return(192);
+  return 192;
 #else
-  return(96);
+  return 96;
 #endif
 }
 
 /*
  * Set baudrate, parity and number of bits.
  */
-void m_setparms(fd, baudr, par, bits, stopb, hwf, swf)
-int fd;
-char *baudr;
-char *par;
-char *bits;
-char *stopb;
-int hwf;
-int swf;
+void m_setparms(int fd, char *baudr, char *par, char *bits, char *stopb,
+                int hwf, int swf)
 {
   int spd = -1;
   int newbaud;
@@ -443,64 +425,67 @@ int swf;
 
   /* We generate mark and space parity ourself. */
   if (bit == '7' && (par[0] == 'M' || par[0] == 'S'))
-	bit = '8';
+    bit = '8';
 
   /* Check if 'baudr' is really a number */
-  if ((newbaud = (atol(baudr) / 100)) == 0 && baudr[0] != '0') newbaud = -1;
+  if ((newbaud = (atol(baudr) / 100)) == 0 && baudr[0] != '0')
+    newbaud = -1;
 
-  switch(newbaud) {
-  	case 0:
+  switch (newbaud) {
+    case 0:
 #ifdef B0
-			spd = B0;	break;
+      spd = B0;
 #else
-			spd = 0;	break;
+      spd = 0;
 #endif
-  	case 3:		spd = B300;	break;
-  	case 6:		spd = B600;	break;
-  	case 12:	spd = B1200;	break;
-  	case 24:	spd = B2400;	break;
-  	case 48:	spd = B4800;	break;
-  	case 96:	spd = B9600;	break;
+      break;
+    case 3:	spd = B300;	break;
+    case 6:	spd = B600;	break;
+    case 12:	spd = B1200;	break;
+    case 24:	spd = B2400;	break;
+    case 48:	spd = B4800;	break;
+    case 96:	spd = B9600;	break;
 #ifdef B19200
-  	case 192:	spd = B19200;	break;
+    case 192:	spd = B19200;	break;
 #else /* B19200 */
 #  ifdef EXTA
-	case 192:	spd = EXTA;	break;
+    case 192:	spd = EXTA;	break;
 #   else /* EXTA */
-	case 192:	spd = B9600;	break;
+    case 192:	spd = B9600;	break;
 #   endif /* EXTA */
 #endif	 /* B19200 */
 #ifdef B38400
-  	case 384:	spd = B38400;	break;
+    case 384:	spd = B38400;	break;
 #else /* B38400 */
 #  ifdef EXTB
-	case 384:	spd = EXTB;	break;
+    case 384:	spd = EXTB;	break;
 #   else /* EXTB */
-	case 384:	spd = B9600;	break;
+    case 384:	spd = B9600;	break;
 #   endif /* EXTB */
 #endif	 /* B38400 */
 #ifdef B57600
-	case 576:	spd = B57600;	break;
+    case 576:	spd = B57600;	break;
 #endif
 #ifdef B115200
-	case 1152:	spd = B115200;	break;
+    case 1152:	spd = B115200;	break;
 #endif
 #ifdef B230400
-	case 2304:	spd = B230400;	break;
+    case 2304:	spd = B230400;	break;
 #endif
   }
-  
+
 #if defined (_BSD43) && !defined(POSIX_TERMIOS)
-  if (spd != -1) tty.sg_ispeed = tty.sg_ospeed = spd;
+  if (spd != -1)
+    tty.sg_ispeed = tty.sg_ospeed = spd;
   /* Number of bits is ignored */
 
   tty.sg_flags = RAW | TANDEM;
   if (par[0] == 'E')
-	tty.sg_flags |= EVENP;
+    tty.sg_flags |= EVENP;
   else if (par[0] == 'O')
-	tty.sg_flags |= ODDP;
+    tty.sg_flags |= ODDP;
   else
-  	tty.sg_flags |= PASS8 | ANYP;
+    tty.sg_flags |= PASS8 | ANYP;
 
   ioctl(fd, TIOCSETP, &tty);
 
@@ -511,12 +496,13 @@ int swf;
 #endif /* _BSD43 && !POSIX_TERMIOS */
 
 #if defined (_V7) && !defined(POSIX_TERMIOS)
-  if (spd != -1) tty.sg_ispeed = tty.sg_ospeed = spd;
+  if (spd != -1)
+    tty.sg_ispeed = tty.sg_ospeed = spd;
   tty.sg_flags = RAW;
   if (par[0] == 'E')
-	tty.sg_flags |= EVENP;
+    tty.sg_flags |= EVENP;
   else if (par[0] == 'O')
-	tty.sg_flags |= ODDP;
+    tty.sg_flags |= ODDP;
 
   ioctl(fd, TIOCSETP, &tty);
 #endif /* _V7 && !POSIX */
@@ -524,25 +510,25 @@ int swf;
 #ifdef POSIX_TERMIOS
 
   if (spd != -1) {
-	cfsetospeed(&tty, (speed_t)spd);
-	cfsetispeed(&tty, (speed_t)spd);
+    cfsetospeed(&tty, (speed_t)spd);
+    cfsetispeed(&tty, (speed_t)spd);
   }
 
   switch (bit) {
-  	case '5':
-  		tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS5;
-  		break;
-  	case '6':
-  		tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS6;
-  		break;
-  	case '7':
-  		tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS7;
-  		break;
-  	case '8':
-	default:
-  		tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS8;
-  		break;
-  }		
+    case '5':
+      tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS5;
+      break;
+    case '6':
+      tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS6;
+      break;
+    case '7':
+      tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS7;
+      break;
+    case '8':
+    default:
+      tty.c_cflag = (tty.c_cflag & ~CSIZE) | CS8;
+      break;
+  }
   /* Set into raw, no echo mode */
   tty.c_iflag =  IGNBRK;
   tty.c_lflag = 0;
@@ -555,15 +541,15 @@ int swf;
   tty.c_cc[VTIME] = 5;
 
   if (swf)
-	tty.c_iflag |= IXON | IXOFF;
+    tty.c_iflag |= IXON | IXOFF;
   else
-	tty.c_iflag &= ~(IXON|IXOFF|IXANY);
+    tty.c_iflag &= ~(IXON|IXOFF|IXANY);
 
   tty.c_cflag &= ~(PARENB | PARODD);
   if (par[0] == 'E')
-	tty.c_cflag |= PARENB;
+    tty.c_cflag |= PARENB;
   else if (par[0] == 'O')
-	tty.c_cflag |= (PARENB | PARODD);
+    tty.c_cflag |= (PARENB | PARODD);
 
   if (stopb[0] == '2')
     tty.c_cflag |= CSTOPB;
@@ -583,22 +569,21 @@ int swf;
 /*
  * Wait for child and return pid + status
  */
-int m_wait(stt)
-int *stt;
+int m_wait(int *stt)
 {
 #if defined (_BSD43) && !defined(POSIX_TERMIOS)
   int pid;
   union wait st1;
-  
+
   pid = wait((void *)&st1);
   *stt = (unsigned)st1.w_retcode + 256 * (unsigned)st1.w_termsig;
-  return(pid);
+  return pid;
 #else
   int pid;
   int st1;
-  
+
   pid = wait(&st1);
   *stt = (unsigned)WEXITSTATUS(st1) + 256 * (unsigned)WTERMSIG(st1);
-  return(pid);
+  return pid;
 #endif
 }
