@@ -21,7 +21,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: sysdep1_s.c,v 1.1 2003/04/01 23:59:51 al-guest Exp $")
+RCSID("$Id: sysdep1_s.c,v 1.2 2003/07/26 15:51:13 al-guest Exp $")
 
 #include "sysdep.h"
 #include "minicom.h"
@@ -35,8 +35,7 @@ struct sockaddr_un portfd_sock_addr;
 /*
  * Flush the buffers
  */
-void m_flush(fd)
-int fd;
+void m_flush(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
