@@ -1,7 +1,7 @@
 /*
  * vt100.h	Header file for the vt100 emulator.
  *
- * 		$Id: vt100.h,v 1.1.1.1 2003/03/30 18:55:54 al-guest Exp $
+ *		$Id: vt100.h,v 1.2 2005/08/04 20:33:34 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -11,6 +11,9 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  */
+#ifndef __MINICOM__SRC__VT100_H__
+#define __MINICOM__SRC__VT100_H__
+#include <stdio.h>
 
 /* Keypad and cursor key modes. */
 #define NORMAL	1
@@ -20,11 +23,14 @@
 #define VT100	1
 #define ANSI	3
 
-/* Prototypes from vt100.c */
-_PROTO( void vt_install, (void(*)(), void (*)(), WIN *));
-_PROTO( void vt_init, (int, int, int, int, int));
-_PROTO( void vt_pinit, (WIN *, int, int));
-_PROTO( void vt_set, (int, int, FILE *, int, int, int, int, int));
-_PROTO( void vt_out, (int ));
-_PROTO( void vt_send, (int ch));
+extern int vt_nl_delay;		/* Delay after CR key */
 
+/* Prototypes from vt100.c */
+void vt_install(void(*)(const char *, int), void (*)(int, int), WIN *);
+void vt_init(int, int, int, int, int);
+void vt_pinit(WIN *, int, int);
+void vt_set(int, int, FILE *, int, int, int, int, int);
+void vt_out(int);
+void vt_send(int ch);
+
+#endif /* ! __MINICOM__SRC__VT100_H__ */
